traits-enaml
============

Traits-Enaml is an extension library to facilitate interoperation of `Enaml
0.9.x` and above with `Traits` and allow a programmer to drive enaml views
using traits models, enable/chaco components and mayavi 3D scenes.

References
==========

Traits https://github.com/enthought/traits
Enable https://github.com/enthought/enable
Mayavi https://github.com/enthought/mayavi
Enaml  https://github.com/nucleic/enaml

Status
======

.. image:: https://api.travis-ci.org/enthought/traits-enaml.png?branch=master
   :target: https://travis-ci.org/enthought/traits-enaml
   :alt: Build status

.. image:: https://coveralls.io/repos/enthought/traits-enaml/badge.png
   :target: https://coveralls.io/r/enthought/traits-enaml
   :alt: Coverage status
